.. _weight-stepsize-adaptation:

WeightStepsizeAdaptation
==========================

.. inheritance-diagram:: gmmvi.optimization.gmmvi_modules.weight_stepsize_adaptation.WeightStepsizeAdaptation gmmvi.optimization.gmmvi_modules.weight_stepsize_adaptation.FixedWeightStepsizeAdaptation gmmvi.optimization.gmmvi_modules.weight_stepsize_adaptation.DecayingWeightStepsizeAdaptation gmmvi.optimization.gmmvi_modules.weight_stepsize_adaptation.ImprovementBasedWeightStepsizeAdaptation
    :parts: -4

.. autoclass:: gmmvi.optimization.gmmvi_modules.weight_stepsize_adaptation.WeightStepsizeAdaptation
   :members:
   :undoc-members:

.. _decaying-weight:

DecayingWeightStepsizeAdaptation
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
.. autoclass:: gmmvi.optimization.gmmvi_modules.weight_stepsize_adaptation.DecayingWeightStepsizeAdaptation
   :members:
   :undoc-members:

.. _fixed-weight:

FixedWeightStepsizeAdaptation
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
.. autoclass:: gmmvi.optimization.gmmvi_modules.weight_stepsize_adaptation.FixedWeightStepsizeAdaptation
   :members:
   :undoc-members:

.. _adaptive-weight:

ImprovementBasedWeightStepsizeAdaptation
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
.. autoclass:: gmmvi.optimization.gmmvi_modules.weight_stepsize_adaptation.ImprovementBasedWeightStepsizeAdaptation
   :members:
   :undoc-members:

.. toctree::
   :maxdepth: 2
   :glob: